==> ben-2.08.tar.gz: ben/queue.h <==
/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2019  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_QUEUE_H
#define BEN_QUEUE_H
#include <time.h>

typedef struct job_t {
	int id;
	
	char *shell;
	char *dir;
	char *options;
	char *name;
	char *cmd;
	
	int restrict_box;
	int forward_box;
	int ran_box;
	
	char *outpath, *errpath;
	int outfd, errfd;
	size_t total_out, total_err;
	
	time_t start_time;
	time_t stop_time;
	
	struct job_t *prev;
	struct job_t *next;
} job;


job *job_new(int id,
	char *shell, char *dir, char *options, char *name, char *cmd);
void job_free(job *t);

int job_open(job *t);
void job_close(job *t, int rmfiles);

int job_matches(job *t, int id, char *dir, char *name);

typedef struct queue_t {
	job *head;
	job *tail;
	int size;
} queue;

void queue_init(queue *q);
void queue_clear(queue *q);

void queue_prepend(queue *q, job *t);
void queue_append(queue *q, job *t);
void queue_unlink(queue *q, job *t);

job *queue_find(queue *q, int id);

#endif

==> ben-2.16.tar.gz: ben/queue.h <==
/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2023  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_QUEUE_H
#define BEN_QUEUE_H
#include <time.h>
#include "pattern.h"

typedef struct job_t {
	int id;
	
	char *shell;
	char *dir;
	char *options;
	char *name;
	char *cmd;
	
	int restrict_box;
	int forward_box;
	int ran_box;
	
	char *outpath, *errpath;
	int outfd, errfd;
	size_t total_out, total_err;
	
	time_t start_time;
	time_t stop_time;
	
	struct job_t *prev;
	struct job_t *next;
} job;


job *job_new(int id,
	char *shell, char *dir, char *options, char *name, char *cmd);
void job_free(job *t);

int job_open(job *t);
void job_close(job *t, int rmfiles);

int job_matches(job *t, pattern *dir, pattern *job);


typedef struct queue_t {
	job *head;
	job *tail;
	int size;
} queue;

void queue_init(queue *q);
void queue_clear(queue *q);

void queue_prepend(queue *q, job *t);
void queue_append(queue *q, job *t);
void queue_unlink(queue *q, job *t);

job *queue_find(queue *q, int id);

#endif
